# Copyright (c) 2022 NF Corporation

# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
# AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

# 2022.6.1
# ZM2371に接続された素子の値を測定する。
# 測定は終了指示「end」が入力されるまで繰り返される。
# 測定データはファイルZM2371_out.txtに出力される。

import pyvisa  # pyvisaモジュールをインポートする。
import time  # timeモジュールをインポートする

rm = pyvisa.ResourceManager()  # インスタンス生成
visa_list = rm.list_resources()  # PCに接続されている機器のVISAリソース名取得

print(visa_list)

usb_1 = visa_list[1]  # 複数機器が接続されている場合[]内の数字で指定。
ZM2371 = rm.open_resource(usb_1)  # 接続
print(ZM2371.query("*IDN?"))


ZM2371.write("*RST")  # リセットをする。
time.sleep(2)  # リセットが終わるまで2秒待つ

hantei = True
while hantei:
    para = input("Z:インピーダンス、R:抵抗、C:コンデンサ、L:インダクタ")
    para = para.upper()
    if para == "Z":
        hantei = False
    elif para == "R":
        hantei = False
    elif para == "C":
        hantei = False
    elif para == "L":
        hantei = False
ZM2371.write(":CALC1:FORM "+para)  # 主パラメータを設定する。
para1 = para

hantei = True
while hantei:
    para = input("Q:品質係数、D:損失係数、P:位相、X:リアクタンス")
    para = para.upper()
    if para == "Q":
        hantei = False
    elif para == "D":
        hantei = False
    elif para == "P":
        para = "PHAS"
        hantei = False
    elif para == "X":
        hantei = False
ZM2371.write(":CALC2:FORM "+para)  # 副パラメータを設定する。
para2 = para

FREQ = "0.1KHZ"
ZM2371.write(":SOUR:FREQ "+FREQ)  # 周波数を設定する。

VOLT = "2V"
ZM2371.write(":SOUR:VOLT "+VOLT)  # 測定電圧レベルの設定。

AUTO = "ON"

ZM2371.write(":RANG:AUTO "+AUTO)  # 測定電圧レベルの設定。

AVE = "1"
ZM2371.write(":AVER:COUN "+AVE)  # 平均回数の設定。
ZM2371.write(":AVER ON")  # 平均の許可。

SPEED = "SLOW"
ZM2371.write(":APER "+SPEED)  # 測定スピードの設定。

ZM2371.write(":INIT:CONT ON")  # 測定完了後トリガ待ちに戻すように設定する。
r = open("ZM2371_out.txt", "w")  # 出力ファイルのオープン
print(para1+","+para2)
r.write(para1+','+para2+'\n')
while True:  # 繰り返し測定する。
    r_txt = ZM2371.query(":FETC?")  # データの読み込みを行う。
    r_txt = r_txt[4:]
    r.write(r_txt)  # 出力ファイルにデータを書き込む。
    print(r_txt)  # データをモニタに表示する。

    if input('enterキーを押すと再測定します。endを入力すると終了します。') == "end":  # 文字を入力する。
        break  # endが入力されたときにループから抜け出す。
print("測定データはZM2371_out.txtに出力されました。")
r.close  # 出力ファイルを閉じる。

print("終了")
